*Youth Unemployment Dynamics
*YUD annualized data from LM histories

*Original: May 3, 2015
*Updated 2023.07.19
*v20

*CK

*Running for 2018, 2016, 2014

*Synthetic panels for the preceding 10 years

/*Defined as in one of three states: O (Out of labor force), E (Employed), U (Unemployed)

Creating annualized stocks of O E and U
Creating flows in destination year (i.e. flow for 2000-2001 is in 2001) 
Creating rates in destination year (i.e rate for 2000-2001 is in 2001)

*Flows denoted by origin and destination (OU is O to U)
*Rates denotes by origin and destination (O_U is OU/O)

*/
set scheme s1mono

***********
*2018
***********

use "LMPS Data/elmps 2018 xs v1.4 all.dta", clear

*Keep the answered
keep if expan_indiv!=.
drop if evrwrk==.

*Keep 15+
keep if age>=15

*Going to use for 2017-2008

keep indid evrwrk unemp1m q7* q53* q52* sex uslf1 dstcrj age expan_indiv q3001 student uswrkst1 usinstsec yrschl agemar1

expand 20

bysort indid: gen year=1997+_n

tabu year

*State in year (O=0, E=1, U=2)
gen state=.

***OLF (state=0)

*Never worked nor searched
replace state=0 if evrwrk==0 & unemp1m!=1 & q5304==2

*If not unemployed but claim still searching 
replace state=0 if evrwrk==0 & unemp1m!=1 & q5306==1

*Searched but after last search
replace state=0 if evrwrk==0 & unemp1m!=1 & q5304==1 & year>=q5307_2b

*Before start of past search - not unemp
replace state=0 if evrwrk==0 & unemp1m!=1 & q5304==1 & year<q5305_2b & q5305_2b!=9998 & q5305_2b!=. 

*Before start of current search - not unemp
replace state=0 if evrwrk==0 & unemp1m!=1 & q5304==1 & year<q5217_2b 

*Before start of unemployment spell
replace state=0 if evrwrk==0 & unemp1m==1 & year<=q5206_2 & q5206_2!=9998 & q5206_2!=.

*O if first status is O and in time frame
replace state=0 if  year>=q7001_2 & year<q7101_2_1 & q7002==1 & q7003==2 & q7101_2_1<9998

*O if gap between school and work
replace state=0 if  year>=q7001_2 & year<q7101_2_1 & q7002==2

*Before left school
replace state=0 if year<q7001_2 & q7001_2!=9998 & q7001_2!=.

*Started workign during school
replace state=0 if year<q7101_2_1 & q7000==1 & q7101_2_1<9998

*Never went to school
replace state=0 if  year<q7101_2_1 & q7101_2_1!=9998 & q7101_2_1!=. & q3001==1


*O if next status is O and in time frame
*After job and before next status (non-employment but not wanting to work)
foreach j of num 1/11 {
local i=`j'+1
*After job and before next status (non-employment but not wanting to work)
replace state=0 if year>=q7124_2_`j' & year<q7101_2_`i' & q7126_`j'==1 & q7127_`j'==2  & q7101_2_`i'<9998  & q7101_2_`i'!=. & q7102_`j'!=1 
*After job and before next status (non-employment by time not report)
replace state=0 if year>=q7124_2_`j' & year<q7101_2_`i' & (q7126_`j'==2 | q7126_`j'==98) & q7101_2_`i'<9998  & q7101_2_`i'!=. & q7102_`j'!=1 
*No next status, not unemployed by responses
replace state=0 if year>=q7124_2_`j' & q7101_2_`i'==. & (q7126_`j'==2 | q7127_`j'==2 | q7126_`j'==98 | q7127_`j'==98) & state==. & q7102_`j'!=1
*No next status, not unemployed by current status not being unemployment
replace state=0 if year>=q7124_2_`j' & q7101_2_`i'==. & (q7126_`j'==1 & q7127_`j'==1) & state==. & unemp1!=1 & q7102_`j'!=1

}
replace state=0 if year>=q7124_2_12 & year<2018 & q7126_12==1 & q7127_12==2 
 
 

***Unemp. (state=2)

*Never worked and during period of search, not currently unemployed are U
replace state=2 if evrwrk==0 & unemp1m!=1 & q5304==1 ///
& year>=q5305_2b & year<q5307_2b & q5305_2b!=9998 & q5307_2b!=9998 & q5305_2b!=. & q5307_2b!=.

*Never worked, currently unemployed, unemployed from start of most recent spell, U
replace state=2 if evrwrk==0 & unemp1m==1 & year>=q5206_2

*U if first status is Unemployed and in the time frame
replace state=2 if year>=q7001_2 & year<q7101_2_1 & q7002==1 & q7003==1 & q7101_2_1<9998


*U if first status is U and in time frame
foreach j of num 1/11 {
local i=`j'+1
replace state=2 if year>=q7124_2_`j' &  year<q7101_2_`i' & q7126_`j'==1 & q7127_`j'==1  & q7101_2_`i'<9998 & q7102_`j'!=1 
*No next status, currently unemployed
replace state=2 if year>=q7124_2_`j' & q7101_2_`i'==. & (q7126_`j'==1 &  q7127_`j'==1) & unemp1==1 & q7102_`j'!=1
}
*Last ones
replace state=2 if year>=q7124_2_12 & year<2018 & q7126_12==1 & q7127_12==1 



***Employed (=1)

*For those who are employed in year (state=1) 
foreach j of num 1/12 {
*Employed and left it
replace state=1 if  year>=q7101_2_`j' & year<q7124_2_`j' & q7124_2_`j'<9998 
*In current job
replace state=1 if year>=q7101_2_`j' & q7102_`j'==1 & state==. 
}


*E if currently employed, back until when started current employment
replace state=1 if year>=dstcrj

*O if still missing state and before first job
replace state=0 if year<q7101_2_1 & q7101_2_1!=. & q7101_2_1!=9998  & state==. 

*O if still missing state, never worked, and not unemployed 
replace state=0 if evrwrk==0 & state==. & unemp1m!=1

*Age in year
sort indid year
bysort indid: gen year_age=age-20+_n

*keep indid expaning 15-64
keep if year_age>=15 & year_age<=64

tabu state, miss

*9998s check
egen check=rowmax(q7001_2 q7101_* q7124_* q52* q53*)

tabu check if state==.
tabu uswrkst1 if state==. & check!=9998
tabu q7101_2_1 if state==. & check!=9998

tabu unemp1m state if year==2017, miss

*browse indid year evrwrk uslf unemp uswrkst1 age q71*_1 q71*_2 q52* q53* if state==. & check!=9998

rename expan_indiv expan

***In school
gen inschool=. 

*Not ever
replace inschool=0 if yrschl==0 
*After left
replace inschool=0 if year_age>6+yrschl
*In school
replace inschool=1 if year_age<=6+yrschl


***Married to date
gen evrmar=0 if agemar1==. | agemar1>year_age
replace evrmar=1 if agemar1<=year_age

keep indid expan sex state year year_age inschool evrmar

gen country=818

keep if state!=.

ren indid oldindid
gen indid="818"+oldind
drop oldindid

save "Eat/2018 OEU.dta", replace



***********
*2016
***********

use "LMPS Data/JLMPS 2016 xs v1.1.dta", clear

* generate missing variables
gen q7106_25=.
gen q7107_24=.
gen q7107_25=.
gen q7107_26=.
gen q7108_24=.
gen q7108_25=.
gen q7108_26=.
gen q7109_24=.
gen q7109_25=.
gen q7109_26=.
gen q7110_21=.
gen q7110_21b=.
gen q7110_22=.
gen q7110_23=.
gen q7110_24=.
gen q7110_25=.
gen q7110_26=.
gen q7110_27=.


*Keep the answered
keep if expan_indiv!=.
drop if evrwrk==.

*Keep 15+
keep if age>=15

*Keep Jordanians
*Keeping only Jordanians
drop if nationality_cl!=1


*Going to use for 2015-2006

keep indid evrwrk unemp1m q7* q5* sex uslf1 dstcrj age expan_indiv job* q3001 yrschl age1stmarr

rename age1stmarr agemar1

expand 20


bysort indid: gen year=1995+_n

tabu year

*State in year (O=0, E=1, U=2)
gen state=.


***OLF (state=0)

*Never worked nor searched
replace state=0 if evrwrk==0 & unemp1m!=1 & q5304==2

*If not unemployed but claim still searching 
replace state=0 if evrwrk==0 & unemp1m!=1 & q5306==1

*Searched but after last search
replace state=0 if evrwrk==0 & unemp1m!=1 & q5304==1 & year>=q5307b 

*Before start of past search - not unemp
replace state=0 if evrwrk==0 & unemp1m!=1 & q5304==1 & year<q5305b & q5305b!=9998 & q5305b!=.

*Before start of current search - not unemp
replace state=0 if evrwrk==0 & unemp1m!=1 & q5304==1 & year<q5214b 

*Before start of unemployment spell
replace state=0 if evrwrk==0 & unemp1m==1 & year<=q5208b & q5208b<9998

*O if first status is O and in time frame
replace state=0 if  year>=q7001b & year<q7101_1b & q7002==1 & q7003==2 & q7101_1b<9998

*O if gap between school and work
replace state=0 if  year>=q7001b & year<q7101_1b & q7002==2

*Before left school
replace state=0 if year<q7001b & q7001b!=9998 & q7001b!=.

*Started workign during school
replace state=0 if year<q7101_1b & q7000==1 & q7101_1b<9998

*Never went to school
replace state=0 if  year<q7101_1b & q7101_1b!=9998 & q7101_1b!=. & q3001==1


*O if next status is O and in time frame

foreach j of num 1/8 {
local i=`j'+1
*After job and before next status (non-employment but not wanting to work)
replace state=0 if year>=q710`j'_21b & year<q710`i'_1b & q710`j'_23==1 & q710`j'_24==2 & q710`i'_1b<9998 & q710`i'_1b!=. 
*After job and before next status (non-employment by time not report)
replace state=0 if year>=q710`j'_21b & year<q710`i'_1b & (q710`j'_23==2 | q710`j'_24==2 | q710`j'_24==98 | q710`j'_24==98) & q710`i'_1b<9998 & q710`i'_1b!=. 
*No next status, not unemployed by responses
replace state=0 if year>=q710`j'_21b & q710`i'_1b==. & (q710`j'_23==2 | q710`j'_24==2) 
*No next status, not unemployed by current status not being unemployment
replace state=0 if year>=q710`j'_21b & q710`i'_1b==. & (q710`j'_23==1 & q710`j'_24==1) & unemp1!=1

} 

*Last ones
replace state=0 if year>=q7109_21b & year<q7110_1b & q7109_23==1 &   q7109_24==2  & q7110_1b<9998
replace state=0 if year>=q7110_21b & year<2016 & q7110_23==1 &   q7110_24==2  


***Unemp. (state=2)

*Never worked and during period of search, not currently unemployed are U
replace state=2 if evrwrk==0 & unemp1m!=1 & q5304==1 ///
 & year>=q5305b & year<q5307b & q5305b!=9998 & q5307b!=9998 & q5305b!=. & q5307b!=. 

*Never worked, currently unemployed, unemployed from start of most recent spell, U
replace state=2 if evrwrk==0 & unemp1m==1 & year>=q5208b
 
 
*U if first status is Unemployed and in the time frame
replace state=2 if year>=q7001b & year<q7101_1b & q7002==1 & q7003==1 & q7101_1b<9998


*U if first status is U and in time frame
foreach j of num 1/8 {
local i=`j'+1
replace state=2 if year>=q710`j'_21b & year<q710`i'_1b & q710`j'_23==1 &   q710`j'_24==1  & q710`i'_1b<9998
*No next status, currently unemployed
replace state=2 if year>=q710`j'_21b & q710`i'_1b==. & q710`j'_23==1 &   q710`j'_24==1  & unemp1==1

}

*Last ones
replace state=2 if year>=q7109_21b & year<q7110_1b & q7109_23==1 &   q7109_24==1  & q7110_1b<9998
replace state=2 if year>=q7110_21b & year<2016 & q7110_23==1 &   q7110_24==1  


***Employed (=1)

*For those who are employed in year (state=1) 

foreach j in  01 02 03 04 05 06 07 08 09 10 {
*During job	
replace state=1 if  year>=q71`j'_1b & year<q71`j'_21b & q71`j'_21b<9998 
*Still in job
replace state=1 if year>=q71`j'_1b & q71`j'_20==2 & state==. 
}

*E if currently employed, back until when started current employment
replace state=1 if year>=dstcrj

*O if still missing state and before first job
replace state=0 if year<q7101_1b & q7101_1b!=. & q7101_1b!=9998  & state==. 

*O if still missing state, never worked, and not unemployed 
replace state=0 if evrwrk==0 & state==. & unemp1m!=1


*Age in year
bysort indid: gen year_age=age-20+_n

*keep indid expaning 15-64
keep if year_age>=15 & year_age<=64

tabu state, miss


*9998s check
egen check=rowmax(q710?_1b q710?_21b q52*b q53*b)

tabu check if state==., miss
*Almost all 9998s. 


***In school
gen inschool=. 

*Not ever
replace inschool=0 if yrschl==0 
*After left
replace inschool=0 if year_age>6+yrschl
*In school
replace inschool=1 if year_age<=6+yrschl

rename expan_indiv expan

***Married to date
gen evrmar=0 if agemar1==. | agemar1>year_age
replace evrmar=1 if agemar1<=year_age

keep indid expan sex state year year_age inschool evrmar

gen country=400

keep if state!=.

rename indid oldindid
gen indid="400"+oldindid
drop oldindid
save "Eat/2016 OEU.dta", replace


***********
*2014
***********

use "LMPS Data/TLMPS 2014 v2.1 all.dta", clear

*Universe
keep if age>=15
drop if expan_indiv==.

*Going to use for 2013-2004

expand 20

bysort indid: gen year=1993+_n

tabu year

*Recovering some dates
replace stat1_y=v207_1_1 if stat1_y==. & stat1_1!=.

*Jobs coded as unemployment
replace stat1_1=1 if stat1_1>=6 & stat1_1<=7 &  stat1_4!=. & stat1_5!=.
replace stat2_1=1 if stat2_1>=6 & stat2_1<=7 &  stat2_4!=. & stat2_5!=.
replace stat3_1=1 if stat3_1>=6 & stat3_1<=7 &  stat3_4!=. & stat3_5!=.
replace stat4_1=1 if stat4_1>=6 & stat4_1<=7 &  stat4_4!=. & stat4_5!=.

*No change if change missing and still in status
replace stat1_17=5 if stat2_y==. & stat2_1==. & stat1_17==. & stat1_1>=1 & stat1_1<=5 & usemp1==1
replace stat2_17=5 if stat3_y==. & stat3_1==. & stat2_17==. & stat2_1>=1 & stat2_1<=5 & usemp1==1
replace stat3_17=5 if stat4_y==. & stat4_1==. & stat3_17==. & stat3_1>=1 & stat3_1<=5 & usemp1==1


*State in year (O=0, E=1, U=2)
gen state=.

*All those who never worked and are not unemployed are 0s
replace state=0 if evrwrk==0 & unemp1m!=1

*O if first status is O and in time frame
*Before left school
replace state=0 if year<v306_1 & v306_1<9998

*Before first status
replace state=0 if year<stat1_y & stat1_y!=. 

*O if first status is O and in time frame
replace state=0 if year>=stat1_y & ((stat2_y>year & stat2_y<.) | uslf1==0) & stat1_1>=8 & stat1_1<=97

*O if second status is O and in time frame
replace state=0 if year>=stat2_y & ((stat3_y>year & stat3_y<.) | uslf1==0) & stat2_1>=8 & stat2_1<=97

*O if third status is O and in time frame
replace state=0 if year>=stat3_y & ((stat4_y>year & stat4_y<.) | uslf1==0) & stat3_1>=8 & stat3_1<=97

*O if fourth status is O and in time frame (have to remain in status)
replace state=0 if year>=stat4_y & uslf1==0 & stat4_1>=8 & stat4_1<=97


*E if first status is E and in time frame
replace state=1 if year>=stat1_y & ((stat2_y>year & stat2_y<.) | stat1_17==5 ) & stat1_1>=1 & stat1_1<=5

*E if second status is E and in time frame
replace state=1 if year>=stat2_y & ((stat3_y>year & stat3_y<.) | stat2_17==5) & stat2_1>=1 & stat2_1<=5

*E if third status is E and in time frame
replace state=1 if year>=stat3_y & ((stat4_y>year & stat4_y<.) | stat3_17==5) & stat3_1>=1 & stat3_1<=5

*E if fourth status is E and in time frame (have to remain in status)
replace state=1 if year>=stat4_y & (usemp1==1 | stat4_17==5) & stat4_1>=1 & stat4_1<=5


*U if first status is U and in time frame
replace state=2 if year>=stat1_y & ((stat2_y>year & stat2_y<.) | unemp1==1) & stat1_1>=6 & stat1_1<=7

*U if second status is U and in time frame
replace state=2 if year>=stat2_y & ((stat3_y>year & stat3_y<.) | unemp1==1) & stat2_1>=6 & stat2_1<=7

*U if third status is U and in time frame
replace state=2 if year>=stat3_y & ((stat4_y>year & stat4_y<.) | unemp1==1) & stat3_1>=6 & stat3_1<=7

*U if fourth status is U and in time frame (have to remain in status)
replace state=2 if year>=stat4_y & (unemp1==1) & stat4_1>=6 & stat4_1<=7

*Set to missing if no data
replace state=. if stat1_y==. & evrwrk==1

*U if currently unemployed, back until when started current unemployment
replace state=2 if v521_b<=year & unemp1==1
replace state=. if (v521_b==. | v521_b==9998 | v521_b==9999) & unemp1==1  & stat1_y==. 
*Difference with Sara, only set to missing if no date for first status

*OLF prior to current unemployment
replace state=0 if v521_b>year & v521_b!=. & v521_b!=9998  & v521_b!=9999 & unemp1m==1 & state==.

*E if currently employed, back until when started current employment
replace state=1 if v510_2<=year 

*If prior to start of first status and no other status, then OLF
replace state=0 if stat1_y>year & state==. & evrwrk==1 & stat1_y!=.
replace state=0 if state==. & unemp1m!=1 & evrwrk==0

*Fix individuals with a first, second, or third status and no subsequent staus
gen check=0
*When misaligned with current status
foreach var of varlist state check {

replace `var'=. if stat1_1>=1 & stat1_1<=5 & stat2_y==. & usemp1!=1
replace `var'=. if stat1_1>=6 & stat1_1<=7 & stat2_y==. & unemp1!=1
replace `var'=. if stat1_1>=8 & stat1_1<=97 & stat2_y==. & uslf1!=0

replace `var'=. if stat2_1>=1 & stat2_1<=5 & stat3_y==. & usemp1!=1
replace `var'=. if stat2_1>=6 & stat2_1<=7 & stat3_y==. & unemp1!=1
replace `var'=. if stat2_1>=8 & stat2_1<=15 & stat3_y==. & uslf1!=0

replace `var'=. if stat3_1>=1 & stat3_1<=5 & stat4_y==. & usemp1!=1
replace `var'=. if stat3_1>=6 & stat3_1<=7 & stat4_y==. & unemp1!=1
replace `var'=. if stat3_1>=8 & stat3_1<=15 & stat4_y==. & uslf1!=0
}

replace check=. if uslf1==. | usemp1==. | (unemp1==. & age<=64) | (unemp1m==1 & stat1_y==. & stat1_1==. & (v521_b==. | v521_b==9998 | v521_b==9999))

*Age in year
sort indid year
bysort indid: gen year_age=age-20+_n

*keep indid expaning 15-64
keep if year_age>=15 & year_age<=64


tabu state, miss
tabu state if check!=., miss

tabu evrwrk if state==.
tabu evrwrk if state==. & check!=.

tabu unemp1 if state==. & evrwrk==0
tabu v521_b if state==. & evrwrk==0

tabu stat1_1 check if state==., miss
tabu stat1_y check if state==. & stat1_1!=., miss

tabu stat1_y stat1_1 if state==. & check!=.
*browse indid year usemp1 unemp1 v521_b uslf1 evrwrk state stat?_*  if state==. & check!=.

*Mostly missing dates

*Use individual expansion weight for TN
rename expan_indiv expan

***In school
gen inschool=. 

*Not ever
replace inschool=0 if yrschl==0 
*After left
replace inschool=0 if year_age>6+yrschl
*In school
replace inschool=1 if year_age<=6+yrschl

***Married to date
gen evrmar=0 if agemar1==. | agemar1>year_age
replace evrmar=1 if agemar1<=year_age

keep indid expan sex state year year_age stat* evrwrk v510_2 inschool evrmar

gen country=788

keep if state!=.
keep if sex!=.
keep if year_age!=.

ren indid oldindid
gen indid="788"+oldindid
drop oldindid

save "Eat/2014 OEU.dta", replace

**************
*Single file
**************

append using "Eat/2018 OEU.dta"
append using "Eat/2016 OEU.dta"

gen round=1 if country==818
replace round=2 if country==400
replace round=3 if country==788

la def Lround 1 "Egypt 2018" 2 "Jordan 2016" 3 "Tunisia 2014", modify

la val round Lround

tabu year round

***Age groups
gen year_ageg=.
replace year_ageg=1 if year_age>=15 & year_age<=29
replace year_ageg=2 if year_age>=30 & year_age<.

la def Lyear_ageg 1 "15-29" 2 "30-64" 4 "Total", modify

la val year_ageg Lyear_ageg

***Sex
la def Lsex 1 "Male" 2 "Female" 3 "Total", modify
la val sex Lsex 

***Marital
la def Levrmar 0 "Never married" 1 "Ever married"
la val evrmar Levrmar

***Stocks

gen O=0
replace O=1 if state==0

gen E=0
replace E=1 if state==1

gen U=0
replace U=1 if state==2


***Flows

sort round indid year

gen OE=0
bysort round indid: replace OE=1 if O[_n-1]==1 & E[_n]==1

gen OU=0
bysort round indid: replace OU=1 if O[_n-1]==1 & U[_n]==1

gen EO=0
bysort round indid: replace EO=1 if E[_n-1]==1 & O[_n]==1

gen EU=0
bysort round indid: replace EU=1 if E[_n-1]==1 & U[_n]==1

gen UO=0
bysort round indid: replace UO=1 if U[_n-1]==1 & O[_n]==1

gen UE=0
bysort round indid: replace UE=1 if U[_n-1]==1 & E[_n]==1

save "Eat/E J T OEU indiv longer.dta", replace

drop if year<2008 & round==1
drop if year<2006 & round==2
drop if year<2004 & round==3

save "Eat/E J T OEU indiv.dta", replace

****Collapsing by year and country

use "Eat/E J T OEU indiv.dta", clear

expand 2
bysort indid year: replace sex=3 if _n==2

expand 2
bysort sex indid year: replace year_ageg=4 if _n==2

collapse O E U OE OU EO EU UO UE (sum) Of=O Ef=E Uf=U OEf=OE OUf=OU EOf=EO EUf=EU UOf=UO UEf=UE [pw=expan]if year_age>=15 & year_age<=64, by(round sex year_ageg year)

isid round year_ageg sex year
sort round year_ageg sex year

*Rates
bysort round year_ageg sex: gen O_E=OE[_n]/O[_n-1]
bysort round year_ageg sex: gen U_E=UE[_n]/U[_n-1]

bysort round year_ageg sex: gen O_U=OU[_n]/O[_n-1]
bysort round year_ageg sex: gen E_U=EU[_n]/E[_n-1]

bysort round year_ageg sex: gen E_O=EO[_n]/E[_n-1]
bysort round year_ageg sex: gen U_O=UO[_n]/U[_n-1]

gen UR=U/(U+E)

sort round year_ageg sex year
order round year_ageg sex year

save "Eat/E J T OEU Collapsed.dta", replace

**********
*Graphing
**********

use "Eat/E J T OEU Collapsed.dta", clear

foreach var of varlist O E U OE OU EO EU UO UE O_E U_E O_U E_U E_O U_O UR {
replace `var'=`var'*100
}

*Run for each stock or flow
*Age group inside over time, M/F/T across the top, countries on the side

*Figure 2: UR

foreach num of numlist 1/3 {

foreach num2 of numlist 1/3 {


graph twoway lowess UR year if year_ageg==1 & sex==`num' & round==`num2', lpatt(dash) lcolor(gs10) lwidth(thick) bw(.3) || ///
lowess UR year if year_ageg==2 & sex==`num' & round==`num2', lpatt(vshortdash) lcolor(gs7) lwidth(thick) bw(.3) ///
|| lowess UR year if year_ageg==4 & sex==`num' & round==`num2', lpatt("l") lcolor(gs0) lwidth(thick) bw(.3) ///
||, ///
       xscale(range(2004 2017)) ylabel(0 (10) 80, gmin labs(small) angle(horizontal)) xtitle("")  ///
       xlabel(2004 2008 2012 2016, labs(small) angle(horizontal)) ytitle("") ///
       legend( rows(2) order(1 "15-29" 2 "30-64" 3 "Total" ///
		) size(3)) xsize(5) ysize(3) graphregion(color(white)) plotregion(margin(zero))

graph save "Graphs and Tables/UR_sex`num'_round`num2'.gph", replace
graph export "Graphs and Tables/UR_sex`num'_round`num2'.tif", replace width(500) 
 }
 }
 
*One graph
grc1leg  "Graphs and Tables/UR_sex1_round1.gph" ///
 "Graphs and Tables/UR_sex2_round1.gph" ///
 "Graphs and Tables/UR_sex3_round1.gph" ///
 "Graphs and Tables/UR_sex1_round2.gph" ///
 "Graphs and Tables/UR_sex2_round2.gph" ///
 "Graphs and Tables/UR_sex3_round2.gph" ///
 "Graphs and Tables/UR_sex1_round3.gph" ///
 "Graphs and Tables/UR_sex2_round3.gph" ///
 "Graphs and Tables/UR_sex3_round3.gph", ///
 ysize(20) xsize(20) cols(3)  ///
 imargin(tiny) title("     Male                                   Female                                   Total", size(3)) ///
 l1title("    Tunisia                          Jordan                           Egypt", size(3))
 
graph display, xsize(20) ysize(20)

graph save "Graphs and Tables/UR_combo.gph", replace
graph export "Graphs and Tables/UR_combo.tif", replace width(1500) 
  

*Figure 3: O_U

foreach num of numlist 1/3 {

foreach num2 of numlist 1/3 {


graph twoway lowess O_U year if year_ageg==1 & sex==`num' & round==`num2', lpatt(dash) lcolor(gs10) lwidth(thick) bw(.3) || ///
lowess O_U year if year_ageg==2 & sex==`num' & round==`num2', lpatt(vshortdash) lcolor(gs7) lwidth(thick) bw(.3) ///
|| lowess O_U year if year_ageg==4 & sex==`num' & round==`num2', lpatt("l") lcolor(gs0) lwidth(thick) bw(.3) ///
||, ///
       xscale(range(2004 2017)) ylabel(0 (2) 10, gmin labs(small) angle(horizontal)) xtitle("")  ///
       xlabel(2004 2008 2012 2016, labs(small) angle(horizontal)) ytitle("") ///
       legend( rows(2) order(1 "15-29" 2 "30-64" 3 "Total" ///
		) size(3)) xsize(5) ysize(3) graphregion(color(white)) plotregion(margin(zero))

graph save "Graphs and Tables/O_U_sex`num'_round`num2'.gph", replace
graph export "Graphs and Tables/O_U_sex`num'_round`num2'.tif", replace width(500) 
 }
 }
 
*One graph
grc1leg  "Graphs and Tables/O_U_sex1_round1.gph" ///
 "Graphs and Tables/O_U_sex2_round1.gph" ///
 "Graphs and Tables/O_U_sex3_round1.gph" ///
 "Graphs and Tables/O_U_sex1_round2.gph" ///
 "Graphs and Tables/O_U_sex2_round2.gph" ///
 "Graphs and Tables/O_U_sex3_round2.gph" ///
 "Graphs and Tables/O_U_sex1_round3.gph" ///
 "Graphs and Tables/O_U_sex2_round3.gph" ///
 "Graphs and Tables/O_U_sex3_round3.gph", ///
 ysize(20) xsize(20) cols(3)  ///
 imargin(tiny) title("     Male                                   Female                                   Total", size(3)) ///
 l1title("    Tunisia                          Jordan                           Egypt", size(3))
 
graph display, xsize(20) ysize(20)

graph save "Graphs and Tables/O_U_combo.gph", replace
graph export "Graphs and Tables/O_U_combo.tif", replace width(1500) 
  
  


*Figure 4 E_U

foreach num of numlist 1/3 {

foreach num2 of numlist 1/3 {


graph twoway lowess E_U year if year_ageg==1 & sex==`num' & round==`num2', lpatt(dash) lcolor(gs10) lwidth(thick) bw(.3) || ///
lowess E_U year if year_ageg==2 & sex==`num' & round==`num2', lpatt(vshortdash) lcolor(gs7) lwidth(thick) bw(.3) ///
|| lowess E_U year if year_ageg==4 & sex==`num' & round==`num2', lpatt("l") lcolor(gs0) lwidth(thick) bw(.3) ///
||, ///
       xscale(range(2004 2017)) ylabel(0 (2) 10 , gmin labs(small) angle(horizontal)) xtitle("")  ///
       xlabel(2004 2008 2012 2016, labs(small) angle(horizontal)) ytitle("") ///
       legend( rows(2) order(1 "15-29" 2 "30-64" 3 "Total" ///
		) size(3)) xsize(5) ysize(3) graphregion(color(white)) plotregion(margin(zero))

graph save "Graphs and Tables/E_U_sex`num'_round`num2'.gph", replace
graph export "Graphs and Tables/E_U_sex`num'_round`num2'.tif", replace width(500) 
 }
 }
 
*One graph
grc1leg  "Graphs and Tables/E_U_sex1_round1.gph" ///
 "Graphs and Tables/E_U_sex2_round1.gph" ///
 "Graphs and Tables/E_U_sex3_round1.gph" ///
 "Graphs and Tables/E_U_sex1_round2.gph" ///
 "Graphs and Tables/E_U_sex2_round2.gph" ///
 "Graphs and Tables/E_U_sex3_round2.gph" ///
 "Graphs and Tables/E_U_sex1_round3.gph" ///
 "Graphs and Tables/E_U_sex2_round3.gph" ///
 "Graphs and Tables/E_U_sex3_round3.gph", ///
 ysize(20) xsize(20) cols(3)  ///
 imargin(tiny) title("     Male                                   Female                                   Total", size(3)) ///
 l1title("    Tunisia                          Jordan                           Egypt", size(3))
 
graph display, xsize(20) ysize(20)

graph save "Graphs and Tables/E_U_combo.gph", replace
graph export "Graphs and Tables/E_U_combo.tif", replace width(1500) 


*Figure 5: U_E

foreach num of numlist 1/3 {

foreach num2 of numlist 1/3 {


graph twoway lowess U_E year if year_ageg==1 & sex==`num' & round==`num2', lpatt(dash) lcolor(gs10) lwidth(thick) bw(.3) || ///
lowess U_E year if year_ageg==2 & sex==`num' & round==`num2', lpatt(vshortdash) lcolor(gs7) lwidth(thick) bw(.3) ///
|| lowess U_E year if  year_ageg==4 & sex==`num' & round==`num2', lpatt("l") lcolor(gs0) lwidth(thick) bw(.3) ///
||, ///
       xscale(range(2004 2017)) ylabel(0 (10) 50, gmin labs(small) angle(horizontal)) xtitle("")  ///
       xlabel(2004 2008 2012 2016, labs(small) angle(horizontal)) ytitle("") ///
       legend( rows(2) order(1 "15-29" 2 "30-64" 3 "Total" ///
		) size(3)) xsize(5) ysize(3) graphregion(color(white)) plotregion(margin(zero))

graph save "Graphs and Tables/U_E_sex`num'_round`num2'.gph", replace
graph export "Graphs and Tables/U_E_sex`num'_round`num2'.tif", replace width(500) 
 }
 }
 
*One graph
grc1leg  "Graphs and Tables/U_E_sex1_round1.gph" ///
 "Graphs and Tables/U_E_sex2_round1.gph" ///
 "Graphs and Tables/U_E_sex3_round1.gph" ///
 "Graphs and Tables/U_E_sex1_round2.gph" ///
 "Graphs and Tables/U_E_sex2_round2.gph" ///
 "Graphs and Tables/U_E_sex3_round2.gph" ///
 "Graphs and Tables/U_E_sex1_round3.gph" ///
 "Graphs and Tables/U_E_sex2_round3.gph" ///
 "Graphs and Tables/U_E_sex3_round3.gph", ///
 ysize(20) xsize(20) cols(3)  ///
 imargin(tiny) title("     Male                                   Female                                   Total", size(3)) ///
 l1title("    Tunisia                          Jordan                           Egypt", size(3))
 
graph display, xsize(20) ysize(20)

graph save "Graphs and Tables/U_E_combo.gph", replace
graph export "Graphs and Tables/U_E_combo.tif", replace width(1500) 
  
*U_O is essentially undetectable, skipping


***********************************************************************
*Decomposing
***********************************************************************

*********************************
*Longer unemployment durations
*********************************

*Figure 6: by duration unemployed
use "Eat/E J T OEU indiv longer.dta", clear

keep if U==1

****Defining a spell
isid indid year
sort indid year

spell, f(_n==1 | (year[_n]-year[_n-1]>1)) by(indid) ///
seq(seq) spell(spell) end(end)

*Duration 1 year
gen unemp_dur=1 if seq==1

*Duration 2 year
replace unemp_dur=2 if seq==2

*Duration 3 year
replace unemp_dur=3 if seq==3

*Duration 4-5
replace unemp_dur=4 if seq>=4 & seq<=5

*Duration 6
replace unemp_dur=5 if seq>=6 & seq<=20

*Drop later years

drop if year<2008 & round==1
drop if year<2006 & round==2
drop if year<2004 & round==3

*Drop uptick years

*drop if round==1 & year==2017
*drop if round==2 & year==2015
*drop if round==3 & year==2013

*Categories

tabu unemp_dur, gen(unemp_dur_)

save "Eat/E J T OEU indiv longer.dta", replace


use "Eat/E J T OEU indiv longer.dta", clear

collapse unemp_dur_* [pw=expan]if year_age>=15 & year_age<=64, by(round year)

gen sex=3

save "Eat/E J T OEU dur T.dta", replace
 
 
use "Eat/E J T OEU indiv longer.dta", clear

collapse unemp_dur_* [pw=expan]if year_age>=15 & year_age<=64, by(round year sex)

save "Eat/E J T OEU dur M F.dta", replace

append using "Eat/E J T OEU dur T.dta"

foreach var of varlist unemp_dur_* {
replace `var'=`var'*100
} 

*In order to stack make temp sums

gen t_1=unemp_dur_1
gen t_2=unemp_dur_1+ unemp_dur_2
gen t_3=unemp_dur_1+ unemp_dur_2 + unemp_dur_3
gen t_4=unemp_dur_1+ unemp_dur_2 + unemp_dur_3+ unemp_dur_4
gen t_5=unemp_dur_1+ unemp_dur_2 + unemp_dur_3+ unemp_dur_4 + unemp_dur_5

foreach num of numlist 1/3 {
foreach num2 of numlist 1/3 {

preserve

keep if round==`num2' & sex==`num' 

twoway (area t_5 year, color(gs13)) (area t_4 year, color(gs10)) ///
(area t_3 year, color(gs7)) (area t_2 year, color(gs4)) ///
(area t_1 year, color(gs1)), xlabel(2004 2008 2012 2016, labs(small)) ylabel(0 (25) 100, val labs(small)) xtitle("") ///
legend(label(1 "6+") label(2 "4-5") label(3 "3") label(4 "2") label(5 "1"))


graph save "Graphs and Tables/decomp_dur_sex`num'_round`num2'.gph", replace
graph export "Graphs and Tables/decomp_dur_sex`num'_round`num2'.tif", replace width(500) 


restore
}
}

*One graph
grc1leg  "Graphs and Tables/decomp_dur_sex1_round1.gph" ///
 "Graphs and Tables/decomp_dur_sex2_round1.gph" ///
 "Graphs and Tables/decomp_dur_sex3_round1.gph" ///
 "Graphs and Tables/decomp_dur_sex1_round2.gph" ///
 "Graphs and Tables/decomp_dur_sex2_round2.gph" ///
 "Graphs and Tables/decomp_dur_sex3_round2.gph" ///
 "Graphs and Tables/decomp_dur_sex1_round3.gph" ///
 "Graphs and Tables/decomp_dur_sex2_round3.gph" ///
 "Graphs and Tables/decomp_dur_sex3_round3.gph", ///
 ysize(20) xsize(20) cols(3)  ///
 imargin(tiny) title("     Male                                   Female                                   Total", size(3)) ///
 l1title("    Tunisia                          Jordan                           Egypt", size(3)) ///
 xcommon ycommon
 
graph display, xsize(20) ysize(20)

graph save "Graphs and Tables/decomp_dur_combo.gph", replace
graph export "Graphs and Tables/decomp_dur_combo.tif", replace width(1500) 




