*Youth Unemployment Dynamics
*YUD desc on unemp

*Original: April 22, 2015
*Updated: March 31, 2017
* Updated July 15, 2023
*v22
*CK

cap log close
log using "Logs/Youth Unemployment Dynamics Descriptives $S_DATE.log", replace

set scheme s1mono

/*Who is unemployed--both unemployment rates and distributions
*7 day, 6 month, 1 year, 2 year definition
*Using the Broad market LF (crlf1/ unemp1m) 
*Distinguish between new and previously worked unemployed
*/

*Fishing out durations
use "LMPS Data/TLMPS 2014 v2.1 all.dta", clear
keep if unemp1m==1

tabu crunempdur_m, miss
tabu v521_a, miss
tabu v521_b, miss
*Replacing if DKs

sort indid
set seed 2439873
gen random=runiform()

*for 2014, random between visit month and start of year
gen temp_m=.
replace temp_m=round(random*visit_m+.5) if v521_b==2014 & crunempdur_m==. 
*for earlier years, random 1-12
replace temp_m=round(random*11+.5) if v521_b<2014 & crunempdur_m==. 

replace crunempdur_m=visit_m-temp_m+12*(2014-v521_b) if crunempdur_m==. & v521_b<=2014

tabu crunempdur_m, miss

keep crunempdur_m indid round
rename crunempdur_m tn_crunempdur_m

ren indid oldindid
gen indid="788"+oldindid
drop oldindid

save "Eat/TLMPS crunempdur_m.dta", replace

*ILMPS Data

use "LMPS data/Integrated LMPs v4.0.dta", clear

*Keeping only 2012 and 2018 for Egypt to show over time
drop if round==1988 | round==2006 | round == 1998

*Keeping only Jordanians
drop if (round==2010 | round==2016) & nationality_cl!=1

set more off

*Fixing TLMPS durations as best able
merge 1:1 indid using "Eat/TLMPS crunempdur_m.dta"

tabu _merge

replace unempdurmth=tn_crunempdur_m if _merge==3
drop _merge tn_crunempdur_m

*Ordered round variable and labels
gen round2=round
	replace round2=1 if round==2012
	replace round2=2 if round==2018
	replace round2=3 if round==2010
	replace round2=4 if round==2016
	replace round2=5 if round==2014

	la def round2lbl 1 "Egypt 2012" 2 "Egypt 2018" 3 "Jordan 2010" 4 "Jordan 2016" 5 "Tunisia 2014"
	la val round2 round2lbl
	tab round2 round

***Special weight for Tunisia because so many missing
*Have to assume missings are random

sum expan_indiv if unemp1m==1 & round2==5

gen Ttemp1=r(sum)

sum expan_indiv if unemp1m==1 & round2==5 & unempdurmth!=.

gen Ttemp2=r(sum)

gen expan_indiv_dur=expan_indiv
replace expan_indiv_dur=expan_indiv*(Ttemp1/Ttemp2) if round2==5 & unempdurmth!=.
replace expan_indiv_dur=. if round2==5 & unempdurmth==. & unemp1m==1


	
****************************************************
*Unemployment rates with different time spans, new vs. prev
****************************************************

**********************************
*Newly unemployed in LF*
***********************************


*new unemployed: 7-day
gen nwunemp7=unemp1m 
replace nwunemp7=0 if (unemp1m==1 & evrwrk==1)

*new unemployed: 6 months
gen nwunemp6mom=unemp1m if unempdurmth!=. | unemp1m==0  
replace nwunemp6mom=0 if (unemp1m==1 & unempdurmth!=.  & evrwrk==1)
replace nwunemp6mom=0 if (unemp1m==1 & unempdurmth<6 & evrwrk==0)

*new unemployed:  1 year
gen nwunemp1yrm=unemp1m if unempdurmth!=. | unemp1m==0  
replace nwunemp1yrm=0 if (unemp1m==1 & unempdurmth!=.  & evrwrk==1)
replace nwunemp1yrm=0 if (unemp1m==1 & unempdurmth<12 & evrwrk==0)

*new unemployed: 2 years
gen nwunemp2yrm=unemp1m if unempdurmth!=. | unemp1m==0  
replace nwunemp2yrm=0 if (unemp1m==1 & unempdurmth!=.  & evrwrk==1)
replace nwunemp2yrm=0 if (unemp1m==1 & unempdurmth<24 & evrwrk==0)


**********************************
*Previously employed in LF*
***********************************

*previously working unemployed: 7 day
gen prvunemp7=unemp1m
replace prvunemp7=0 if (unemp1m==1  & evrwrk==0)

*previously working unemployed:6 months
gen prvunemp6mom=unemp1m if unempdurmth!=. | unemp1m==0  
replace prvunemp6mom=0 if (unemp1m==1 & unempdurmth!=.  & evrwrk==0)
replace prvunemp6mom=0 if (unemp1m==1 & unempdurmth<6 & evrwrk==1)

*previously working unemployed:1 years
gen prvunemp1yrm=unemp1m if unempdurmth!=. | unemp1m==0  
replace prvunemp1yrm=0 if (unemp1m==1 & unempdurmth!=.  & evrwrk==0)
replace prvunemp1yrm=0 if (unemp1m==1 & unempdurmth<12 & evrwrk==1)

*previously working unemployed:2 years
gen prvunemp2yrm=unemp1m if unempdurmth!=. | unemp1m==0  
replace prvunemp2yrm=0 if (unemp1m==1 & unempdurmth!=.  & evrwrk==0)
replace prvunemp2yrm=0 if (unemp1m==1 & unempdurmth<24 & evrwrk==1)

**********************************
*With search/Reason not searching
***********************************

*Age 15-29 vs. 30-64

gen age_cat=1 if age>=15 & age<=29
replace age_cat=2 if age>=30 & age<=64

table sex round age_cat [pw=expan_indiv], c(mean unemp1m mean unempsr1m) row col scol

tabu rsnnosrch country if round==2016 | round==2014 | round==2018 [aw=expan_indiv], col nofreq

**********************************
*Share of LF new unemp, prev unemp
***********************************

*Figure 1

isid indid
expand 2
bysort indid: replace sex=3 if _n==2

la def sex 3 "Total", modify

preserve

collapse nwunemp* prvunemp* if age>=15 & age<=64  ///
	[aw=expan_indiv], by(sex round2)
	
	rename *mom * 
	rename *yrm *

reshape long nwunemp@ prvunemp@, i(sex round2) j(length)

replace nwunemp=nwunemp*100
replace prvunemp=prvunemp*100

recode length (7=1) (6=2) (1=3) (2=4)

la def Llength 1 "7-day" 2 "6-month" 3 "1-year" 4 "2-year"
la val length Llength

	
graph hbar nwunemp prvunemp, by(sex, note("") col(1) compact) over(length, label(labsize(1.8))) over(round2, label(labsize(3))) stack ytitle("Percentage of the labor force", size(3)) legend(span label(1 "Unemployed new entrants") label(2 "Unemployed previously worked") size(2.5)) blabel(bar, format(%2.0f) pos(center) size(1.5)) yscale(range(0 40)) ylab(,nogrid) ysize(20) xsize(15) bar(1, color(gs9)) bar(2, color(gs13))

graph save "Graphs and Tables/URlengthprevnew.gph", replace
graph export "Graphs and Tables/URlengthprevnew.tif", width(1500) replace

sort sex round2 length

**Appendix figure

gen nw_rat=nwunemp/(prvunemp+nwunemp)*100

graph hbar nw_rat, by(sex, note("") col(1) compact) over(length, label(labsize(1.8))) over(round2, label(labsize(3))) stack ytitle("Percentage of the unemployed who are new entrants", size(3)) legend(off) blabel(bar, format(%2.0f) pos(outside) size(1.5)) yscale(range(0 40)) ylab(,nogrid) ysize(20) xsize(15) bar(1, color(gs1)) bar(2, color(gs13))

graph save "Graphs and Tables/URrationew.gph", replace
graph export "Graphs and Tables/URrationew.tif", width(1500) replace


restore

**********************************
*Appendix Figure: By age group
***********************************


*7 day
gen yng_unemp7=(age_cat==1 & (prvunemp7==1 | nwunemp7==1)) if (prvunemp7!=. | nwunemp7!=.)
gen old_unemp7=(age_cat==2 & (prvunemp7==1 | nwunemp7==1)) if (prvunemp7!=. | nwunemp7!=.)

* 6 mo. 
gen yng_unemp6mom=(age_cat==1 & (prvunemp6mom==1 | nwunemp6mom==1)) if (prvunemp6mom!=. | nwunemp6mom!=.)
gen old_unemp6mom=(age_cat==2 & (prvunemp6mom==1 | nwunemp6mom==1)) if (prvunemp6mom!=. | nwunemp6mom!=.)

* 1 year
gen yng_unemp1yrm=(age_cat==1 & (prvunemp1yrm==1 | nwunemp1yrm==1)) if (prvunemp1yrm!=. | nwunemp1yrm!=.)
gen old_unemp1yrm=(age_cat==2 & (prvunemp1yrm==1 | nwunemp1yrm==1)) if (prvunemp1yrm!=. | nwunemp1yrm!=.)

* 2 year
gen yng_unemp2yrm=(age_cat==1 & (prvunemp2yrm==1 | nwunemp2yrm==1)) if (prvunemp2yrm!=. | nwunemp2yrm!=.)
gen old_unemp2yrm=(age_cat==2 & (prvunemp2yrm==1 | nwunemp2yrm==1)) if (prvunemp2yrm!=. | nwunemp2yrm!=.)



preserve

collapse yng_unemp* old_unemp* if age>=15 & age<=64  ///
	[aw=expan_indiv], by(sex round2)
	
	rename *mom * 
	rename *yrm *

reshape long yng_unemp@ old_unemp@, i(sex round2) j(length)

replace yng_unemp=yng_unemp*100
replace old_unemp=old_unemp*100

recode length (7=1) (6=2) (1=3) (2=4)

la def Llength 1 "7-day" 2 "6-month" 3 "1-year" 4 "2-year"
la val length Llength

	
graph hbar yng_unemp old_unemp, by(sex, note("") col(1) compact) over(length, label(labsize(1.8))) over(round2, label(labsize(3))) stack ytitle("Percentage of the labor force", size(3)) legend(span label(1 "Unemployed 15-29") label(2 "Unemployed 30-64") size(2.5)) blabel(bar, format(%2.0f) pos(center) size(1.5)) yscale(range(0 40)) ylab(,nogrid) ysize(20) xsize(15) bar(1, color(gs9)) bar(2, color(gs13))

graph save "Graphs and Tables/URlengthage.gph", replace
graph export "Graphs and Tables/URlengthprevage.tif", width(1500) replace

sort sex round2 length

restore

*Stat: Footnote on ed. 


use "LMPS data/Integrated LMPs v4.0.dta", clear

*Keeping only 2012 and 2018 for Egypt to show over time
keep if round==2018 | round==2016 | round == 2014

*Keeping only Jordanians
drop if round==2016 & nationality_cl!=1

*Keeping 15-64
keep if age>=15 & age<=64

gen owneduc=1 if educ1d<=3
replace owneduc=2 if educ1d==4
replace owneduc=3 if educ1d>=5 & educ1d<.
label define Lowneduc 1 "Low" 2 "Intermediate" 3 "High", modify
label val owneduc Lowneduc

* Father and Mother at least basic to be high SES
gen highSES=(fteducst>=3  & mteducst>=3) if fteducst<. & mteducst<.


gen educSES=owneduc
replace educSES=4 if owneduc==3 & highSES==1
label define LeducSES 1 "Low" 2 "Intermediate" 3 "High Ed.-low SES" 4 "High Ed.-high SES", modify
label val educSES LeducSES

tabu highSES country [aw=expan_indiv] if owneduc==3, col nofreq


**********************************
*Appendix Figure: Panel transitions
***********************************

*Egypt

set scheme s1mono

use "LMPS Data/elmps 2018 panel 98_18 v2.0.dta", clear

expand 2
bysort Findid: replace sex_12=3 if _n==2 & sex_12!=.
la def sex 3 "Total", modify

expand 2
bysort sex_12 Findid: gen age_cat=3 if _n==2 & age_12!=.
replace age_cat=1 if age_12>=15 & age_12<=29 & age_cat==.
replace age_cat=2 if age_12>=30 & age_12<=64 & age_cat==.

la def Lage_cat 1 "15-29" 2 "30-64" 3 "Total"
la val age_cat Lage_cat

egen combo=group(age_cat sex_12), label

la def workstat 1 "Emp." 2 "Unemp." 3 "OLF", modify

*2012-2018

catplot crwrkst1_18 if age_12>=15 & age_18<=64 & crwrkst1_12!=. & crwrkst1_18!=. [aw=panel_wt_12_18], by(combo, note("") row(3) title("")) over(crwrkst1_12) percent(crwrkst1_12 combo) stack asy legend(off) l1title("2012 status") ytitle("Percentage") blabel(bar, format(%2.0f) pos(center) size(3)) ylabel(, nogrid) legend(row(1) title("2018 status", size(4))) plotregion(margin(none))

graph save "Graphs and Tables/EG_panel.gph", replace
graph export "Graphs and Tables/EG_panel.tif", width(1500) replace

*Jordan


use "LMPS Data/JLMPS 2016 panel v1.1.dta", clear

expand 2
bysort Findid: replace sex_10=3 if _n==2 & sex_10!=.
la def sex 3 "Total", modify

expand 2
bysort sex_10 Findid: gen age_cat=3 if _n==2 & age_10!=.
replace age_cat=1 if age_10>=15 & age_10<=29 & age_cat==.
replace age_cat=2 if age_10>=30 & age_10<=64 & age_cat==.

la def Lage_cat 1 "15-29" 2 "30-64" 3 "Total"
la val age_cat Lage_cat

egen combo=group(age_cat sex_10), label

la def workstat 1 "Emp." 2 "Unemp." 3 "OLF", modify

*2012-2018

catplot crwrkst1_16 if age_10>=15 & age_16<=64 & crwrkst1_10!=. & crwrkst1_16!=. [aw=panel_wt_10_16], by(combo, note("") row(3) title("")) over(crwrkst1_10) percent(crwrkst1_10 combo) stack asy legend(off) l1title("2010 status") ytitle("Percentage") blabel(bar, format(%2.0f) pos(center) size(3)) ylabel(, nogrid) legend(row(1) title("2016 status", size(4))) plotregion(margin(none))

graph save "Graphs and Tables/JO_panel.gph", replace
graph export "Graphs and Tables/JO_panel.tif", width(1500) replace


log close


