*Youth Unemployment Dynamics
*YUD competing risk for entering unemployment

*Original: May 8, 2015
* 2023.07.19
*v17

*CK

*Running for 2014, 2016, 2018

*Use synthetic panels for the preceding 10 years created in YUD annualized

/*
Creating O or E spells

Using entrants into the state for the preceding decade

Estimating discrete time competing risk model (logit)

*/

capture log close
log using "Logs/competing risk enter U log $S_DATE.log", replace

************************
*Spells - O to ?
*************************

use "Eat/E J T OEU indiv.dta", clear

sort round indid year

merge m:1 indid using "LMPS data/Integrated LMPs v4.0.dta"

drop if _merge==2

drop _merge

****Stock at risk of transition (incl. LC)
isid indid year
sort indid year

*Not estimating duration dependence

***Outcome

gen O_to=.
replace O_to=0 if state[_n-1]==0 & state==0 & indid[_n-1]==indid
replace O_to=1 if state[_n-1]==0 & state==1 & indid[_n-1]==indid
replace O_to=2 if state[_n-1]==0 & state==2 & indid[_n-1]==indid

la def LO_to 0 "O - O" 1 "O - E" 2 "O - U"
la val O_to LO_to

***Drop right censored years

drop if year==2017 & round==1
drop if year==2015 & round==2
drop if year==2013 & round==3

*************
***Covariates
************* 

gen owneduc=1 if educ1d<=3
replace owneduc=2 if educ1d==4
replace owneduc=3 if educ1d>=5 & educ1d<.
label define Lowneduc 1 "Low" 2 "Intermediate" 3 "High", modify
label val owneduc Lowneduc

* Father and Mother at least basic to be high SES
gen highSES=(fteducst>=3  & mteducst>=3) if fteducst<. & mteducst<.


gen educSES=owneduc
replace educSES=4 if owneduc==3 & highSES==1
label define LeducSES 1 "Low" 2 "Intermediate" 3 "High Ed.-low SES" 4 "High Ed.-high SES", modify
label val educSES LeducSES

gen rural=1 if urban==2
replace rural=0 if urban==1

*Current not start year
gen cyr_group=1 if year>=2004 & year<=2007
replace cyr_group=2 if year>=2008 & year<=2010
replace cyr_group=3 if year>=2011 & year<=2013
replace cyr_group=4 if year>=2014 & year<=2016

la def Lcyr_group 1 "2004-2007" 2 "2008-2010" ///
3 "2011-2013" 4 "2014-2016" 

la val cyr_group Lcyr_group


***Model testing for O to U differences by country and sex
mlogit O_to i.round##i.sex##i.year_ageg i.round##i.sex##b4.educSES i.round##i.sex##i.rural i.round##i.sex##i.cyr_group i.round##i.sex##i.inschool i.round##i.sex##i.evrmar [pw=expan_indiv]


margins 1.round#1.sex 1.round#2.sex 2.round#1.sex 2.round#2.sex 3.round#1.sex 3.round#2.sex, noestimcheck post pr(outcome(2))

*Test for gender differences in each country
*Egypt
test 1.round#1.sex=1.round#2.sex
*Jordan
test 2.round#1.sex=2.round#2.sex
*Tunisia
test 3.round#1.sex=3.round#2.sex

*Test across countries, within sex
*Egypt v. Jordan, men
test 1.round#1.sex=2.round#1.sex
*Egypt v. Jordan, women
test 1.round#2.sex=2.round#2.sex
*Egypt v. Tunisia, men
test 1.round#1.sex=3.round#1.sex
*Egypt v. Tunisia, women
test 1.round#2.sex=3.round#2.sex
*Tunisia v. Jordan, men
test 3.round#1.sex=2.round#1.sex
*Tuniisa v. Jordan, women
test 3.round#2.sex=2.round#2.sex

***Model testing for O to E differences by country and sex
mlogit O_to i.round##i.sex##i.year_ageg i.round##i.sex##b4.educSES i.round##i.sex##i.rural i.round##i.sex##i.cyr_group i.round##i.sex##i.inschool i.round##i.sex##i.evrmar [pw=expan_indiv]


margins 1.round#1.sex 1.round#2.sex 2.round#1.sex 2.round#2.sex 3.round#1.sex 3.round#2.sex, noestimcheck post pr(outcome(1))

*Test for gender differences in each country
*Egypt
test 1.round#1.sex=1.round#2.sex
*Jordan
test 2.round#1.sex=2.round#2.sex
*Tunisia
test 3.round#1.sex=3.round#2.sex

***Model testing for O to O differences by country and sex
mlogit O_to i.round##i.sex##i.year_ageg i.round##i.sex##b4.educSES i.round##i.sex##i.rural i.round##i.sex##i.cyr_group i.round##i.sex##i.inschool i.round##i.sex##i.evrmar [pw=expan_indiv]


margins 1.round#1.sex 1.round#2.sex 2.round#1.sex 2.round#2.sex 3.round#1.sex 3.round#2.sex, noestimcheck post pr(outcome(0))

*Test for gender differences in each country
*Egypt
test 1.round#1.sex=1.round#2.sex
*Jordan
test 2.round#1.sex=2.round#2.sex
*Tunisia
test 3.round#1.sex=3.round#2.sex


***Loop for competing risk

*Round/country
foreach num of numlist 1/3 {
	*Sex
	foreach num2 of numlist 1/2 {
		
*Model 
mlogit O_to i.year_ageg b4.educSES i.rural i.cyr_group i.inschool i.evrmar [pw=expan_indiv]  if round==`num' & sex==`num2',  rrr cluster(Fpsu) 

estimates store O_to_`num'_s_`num2'

	}
}




esttab O_to_*_s_* using "Graphs and Tables/O_to_MNL.csv", cells(b(star fmt(%9.3f)) se(par))  ///     
 order(*year_ageg *educSES *rural 2.cyr_group 3.cyr_group 4.cyr_group *inschool *evrmar) stats(N, fmt(%9.0g))   ///
	legend  mlabel("Egypt Males" "Egypt Females" "Jordan Males" "Jordan Females" "Tunisia Males" "Tunisia Females") ///
	refcat(2.year_ageg "Age group (15-29 omit.)" ///
	1.educSES "Education and SES (higher ed.- high SES omit.)" 1.rural "Rural (urban omit.)" ///
	2.cyr_group "Current year (2004-07 omit. Jordan Tunsia & 2008-2010 omit. Egypt)" 1.inschool "In school (not in school omit.)" 1.evrmar "Ever married (not yet omit.)", nolabel)       ///
	coeflabels(2.year_ageg "30-64" 1.educSES "Low" 2.educSES "Intermediate" 3.educSES "High ed. - low SES" 1.rural "Rural" 2.cyr_group "2008-2010" 3.cyr_group "2011-13" 4.cyr_group "2014-16" 1.inschool "In school" 1.evrmar "Ever married") ///
	eform replace noomit nobase
	

	
************************
*Spells - E to ?
*************************

use "Eat/E J T OEU indiv.dta", clear

sort round indid year

merge m:1 indid using "LMPS data/Integrated LMPs v4.0.dta"

drop if _merge==2

drop _merge

****Stock at risk of transition (incl. LC)
isid indid year
sort indid year

*Not estimating duration dependence

***Outcome

gen E_to=.
replace E_to=0 if state[_n-1]==1 & state==1 & indid[_n-1]==indid
replace E_to=1 if state[_n-1]==1 & state==0 & indid[_n-1]==indid
replace E_to=2 if state[_n-1]==1 & state==2 & indid[_n-1]==indid

la def LE_to 0 "E - E" 1 "E - O" 2 "E - U"
la val E_to LE_to

***Drop right censored years

drop if year==2017 & round==1
drop if year==2015 & round==2
drop if year==2013 & round==3

*************
***Covariates
************* 

gen owneduc=1 if educ1d<=3
replace owneduc=2 if educ1d==4
replace owneduc=3 if educ1d>=5 & educ1d<.
label define Lowneduc 1 "Low" 2 "Intermediate" 3 "High", modify
label val owneduc Lowneduc

* Father and Mother at least basic to be high SES
gen highSES=(fteducst>=3  & mteducst>=3) if fteducst<. & mteducst<.


gen educSES=owneduc
replace educSES=4 if owneduc==3 & highSES==1
label define LeducSES 1 "Low" 2 "Intermediate" 3 "High Ed.-low SES" 4 "High Ed.-high SES", modify
label val educSES LeducSES

gen rural=1 if urban==2
replace rural=0 if urban==1

*Current not start year
gen cyr_group=1 if year>=2004 & year<=2007
replace cyr_group=2 if year>=2008 & year<=2010
replace cyr_group=3 if year>=2011 & year<=2013
replace cyr_group=4 if year>=2014 & year<=2016

la def Lcyr_group 1 "2004-2007" 2 "2008-2010" ///
3 "2011-2013" 4 "2014-2016" 

la val cyr_group Lcyr_group


***Model testing for differences by country and sex
*mlogit E_to i.round##i.sex##i.year_ageg i.round##i.sex##b4.educSES i.round##i.sex##i.rural i.round##i.sex##i.cyr_group i.round##i.sex##i.evrmar [pw=expan_indiv]
*Not convergent

mlogit E_to i.round##i.sex [pw=expan_indiv]

margins 1.round#1.sex 1.round#2.sex 2.round#1.sex 2.round#2.sex 3.round#1.sex 3.round#2.sex, noestimcheck post pr(outcome(2))

*Test for gender differences in each country
*Egypt
test 1.round#1.sex=1.round#2.sex
*Jordan
test 2.round#1.sex=2.round#2.sex
*Tunisia
test 3.round#1.sex=3.round#2.sex

*Test across countries, within sex
*Egypt v. Jordan, men
test 1.round#1.sex=2.round#1.sex
*Egypt v. Jordan, women
test 1.round#2.sex=2.round#2.sex
*Egypt v. Tunisia, men
test 1.round#1.sex=3.round#1.sex
*Egypt v. Tunisia, women
test 1.round#2.sex=3.round#2.sex
*Tunisia v. Jordan, men
test 3.round#1.sex=2.round#1.sex
*Tuniisa v. Jordan, women
test 3.round#2.sex=2.round#2.sex



***Loop for competing risk

*Round/country
foreach num of numlist 1/2 {
	*Sex
	foreach num2 of numlist 1/2 {
		
*Model 
mlogit E_to i.year_ageg b4.educSES i.rural i.cyr_group i.evrmar [pw=expan_indiv]  if round==`num' & sex==`num2',  rrr cluster(Fpsu)

estimates store E_to_`num'_s_`num2'

	}
}

*Round/country
foreach num of numlist 3 {
	*Sex
	foreach num2 of numlist 2 1 {
		
*Model 
mlogit E_to i.year_ageg b4.educSES i.rural i.cyr_group i.evrmar [pw=expan_indiv]  if round==`num' & sex==`num2',  rrr cluster(Fpsu) iterate(30)

estimates store E_to_`num'_s_`num2'

	}
}


esttab E_to_*_s_* using "Graphs and Tables/E_to_MNL.csv", cells(b(star fmt(%9.3f)) se(par))  ///     
 order(*year_ageg *educSES *rural 2.cyr_group 3.cyr_group 4.cyr_group) stats(N, fmt(%9.0g))   ///
	legend  mlabel("Egypt Males" "Egypt Females" "Jordan Males" "Jordan Females" "Tunisia Females" "Tunisia Males") ///
	refcat(2.year_ageg "Age group (15-29 omit.)" ///
	1.educSES "Education and SES (higher ed.- high SES omit.)" 1.rural "Rural (urban omit.)" ///
	2.cyr_group "Current year (2004-07 omit. Jordan Tunsia & 2008-2010 omit. Egypt)" 1.evrmar "Ever married (not yet omit.)", nolabel)       ///
	coeflabels(2.year_ageg "30-64" 1.educSES "Low" 2.educSES "Intermediate" 3.educSES "High ed. - low SES" 1.rural "Rural" 2.cyr_group "2008-2010" 3.cyr_group "2011-13" 4.cyr_group "2014-16" 1.evrmar "Ever married") ///
	eform replace noomit nobase
	


log close
